Configuration file reference
============================

SOSSE can be configured through the configuration file ``/etc/sosse/sosse.conf``. Configuration variables are grouped in 3 sections, depending
on which component they affect. Modyifing any of these option requires restarting the crawlers or the wewb interface.

.. include:: config_file_generated.rst
